# ps3-update-dl

[![Build Status](https://img.shields.io/travis/iomintz/ps3-update-dl/trunk.svg?label=tests)](https://travis-ci.com/iomintz/ps3-update-dl)

Downloads all updates for a given title directly from the PlayStation servers.

## License

© io mintz <io@mintz.cc>

ps3-update-dl is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

ps3-update-dl is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with ps3-update-dl. If not, see <https://www.gnu.org/licenses/>.
